@@ -27,6 +27,7 @@
 #include <thunar/thunar-icon-factory.h>
 #include <thunar/thunar-icon-renderer.h>
 #include <thunar/thunar-private.h>
+#include <thunar/thunar-util.h>
 
 
 
@@ -38,6 +39,9 @@ enum
   PROP_EMBLEMS,
   PROP_FOLLOW_STATE,
   PROP_SIZE,
+  PROP_HIGHLIGHT_COLOR,
+  PROP_ROUNDED_CORNERS,
+  PROP_HIGHLIGHTING_ENABLED,
 };
 
 
@@ -154,6 +158,46 @@ thunar_icon_renderer_class_init (ThunarIconRendererClass *klass)
                                                       THUNAR_TYPE_ICON_SIZE,
                                                       THUNAR_ICON_SIZE_32,
                                                       G_PARAM_CONSTRUCT | EXO_PARAM_READWRITE));
+
+
+
+  /**
+   * ThunarIconRenderer:highlight-color:
+   *
+   * The color with which the cell should be highlighted.
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_HIGHLIGHT_COLOR,
+                                   g_param_spec_string ("highlight-color", "highlight-color", "highlight-color",
+                                                        NULL,
+                                                        EXO_PARAM_READWRITE));
+
+
+
+  /**
+   * ThunarIconRenderer:rounded-corners:
+   *
+   * Determines if the cell should be clipped to rounded-corners.
+   * Useful when highlighting is enabled & a highlight color is set.
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_ROUNDED_CORNERS,
+                                   g_param_spec_boolean ("rounded-corners", "rounded-corners", "rounded-corners",
+                                                         FALSE,
+                                                         EXO_PARAM_READWRITE));
+
+
+
+  /**
+   * ThunarIconRenderer:highlighting-enabled:
+   *
+   * Determines if the cell background should be drawn with highlight color.
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_HIGHLIGHTING_ENABLED,
+                                   g_param_spec_boolean ("highlighting-enabled", "highlighting-enabled", "highlighting-enabled",
+                                                         FALSE,
+                                                         EXO_PARAM_READWRITE));
 }
 
 
@@ -177,6 +221,7 @@ thunar_icon_renderer_finalize (GObject *object)
     g_object_unref (G_OBJECT (icon_renderer->drop_file));
   if (G_LIKELY (icon_renderer->file != NULL))
     g_object_unref (G_OBJECT (icon_renderer->file));
+  g_free (icon_renderer->highlight_color);
 
   (*G_OBJECT_CLASS (thunar_icon_renderer_parent_class)->finalize) (object);
 }
@@ -213,6 +258,18 @@ thunar_icon_renderer_get_property (GObject    *object,
       g_value_set_enum (value, icon_renderer->size);
       break;
 
+    case PROP_HIGHLIGHT_COLOR:
+      g_value_set_string (value, icon_renderer->highlight_color);
+      break;
+
+    case PROP_ROUNDED_CORNERS:
+      g_value_set_boolean (value, icon_renderer->rounded_corners);
+      break;
+
+    case PROP_HIGHLIGHTING_ENABLED:
+      g_value_set_boolean (value, icon_renderer->highlighting_enabled);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -255,6 +312,19 @@ thunar_icon_renderer_set_property (GObject      *object,
       icon_renderer->size = g_value_get_enum (value);
       break;
 
+    case PROP_HIGHLIGHT_COLOR:
+      g_free (icon_renderer->highlight_color);
+      icon_renderer->highlight_color = g_value_dup_string (value);
+      break;
+
+    case PROP_ROUNDED_CORNERS:
+      icon_renderer->rounded_corners = g_value_get_boolean (value);
+      break;
+
+    case PROP_HIGHLIGHTING_ENABLED:
+      icon_renderer->highlighting_enabled = g_value_get_boolean (value);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -405,6 +475,9 @@ thunar_icon_renderer_render (GtkCellRenderer     *renderer,
 
   g_object_get (renderer, "is-expanded", &is_expanded, NULL);
 
+  if (THUNAR_ICON_RENDERER (renderer)->highlighting_enabled)
+    thunar_util_clip_view_background (renderer, cr, background_area, widget, flags);
+
   /* determine the icon state */
   icon_state = (icon_renderer->drop_file != icon_renderer->file)
              ? is_expanded
